/*******************************************************************************
 * Copyright (c) 2013 protos software gmbh (http://www.protos.de).
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 * 
 * CONTRIBUTORS:
 * 		Eyrak Paen (initial contribution)
 * 
 *******************************************************************************/
package org.eclipse.etrice.core.common.ui.labeling

import com.google.inject.Inject
import org.eclipse.emf.edit.ui.provider.AdapterFactoryLabelProvider
import org.eclipse.etrice.core.common.base.Import
import org.eclipse.jface.resource.JFaceResources
import org.eclipse.jface.viewers.StyledString
import org.eclipse.jface.viewers.StyledString.Styler
import org.eclipse.swt.graphics.RGB
import org.eclipse.xtext.ui.label.DefaultEObjectLabelProvider
import org.eclipse.xtext.ui.label.StylerFactory

/**
 * Provides labels for a EObjects.
 * 
 * see http://www.eclipse.org/Xtext/documentation.html#labelProvider
 */
class BaseLabelProvider extends DefaultEObjectLabelProvider {

	protected static final String KEYWORD_COLOR = "KEYWORD_COLOR";

	@Inject
	protected StylerFactory stylerFactory;
	
	protected Styler keywordStyler = null;
	protected Styler typeStyler = null;
	
	@Inject
	new(AdapterFactoryLabelProvider delegate) {
		super(delegate);
		
		JFaceResources.getColorRegistry().put(KEYWORD_COLOR, new RGB(50, 50, 50));
	}

	def String image(Import mdl) {
		return null;
	}
	
	def StyledString text(Import im) {
		if (im.getImportedNamespace() === null) {
			var txt = new StyledString("import model " + im.getImportURI())
			txt.setStyle(0, 12, getKeywordStyler())
			return txt
		} else {
			var txt = new StyledString("import ns " + im.getImportedNamespace())
			txt.setStyle(0, 9, getKeywordStyler())
			return txt
		}
	}
	
	def protected Styler getKeywordStyler() {
		// Bug 576866 
//		if (keywordStyler===null) {
//			var font = JFaceResources.getFontDescriptor(JFaceResources.TEXT_FONT)
//			var boldFont = font.setStyle(SWT.BOLD)
//			keywordStyler = stylerFactory.createStyler(boldFont, KEYWORD_COLOR, null)
//		}
//		return keywordStyler
	}

	def protected Styler getTypeStyler() {
		// Bug 576866 
//		if (typeStyler===null) {
//			var font = JFaceResources.getFontDescriptor(JFaceResources.TEXT_FONT)
//			var italicFont = font.setStyle(SWT.ITALIC)
//			typeStyler = stylerFactory.createStyler(italicFont, null, null)
//		}
//		return typeStyler
	}
}
